r57488 - in /trunk/libxml-xql-perl: debian/README.source debian/changelog debian/control debian/patches/long-double.patch debian/patches/series debian/patches/spelling.patch debian/rules debian/source/ debian/source/format lib/XML/XQL.pm t/xql_sin2.t

ansgar-guest at users.alioth.debian.org ansgar-guest at users.alioth.debian.org
Wed May 5 10:22:23 UTC 2010


Author: ansgar-guest
Date: Wed May  5 10:22:03 2010
New Revision: 57488

URL: http://svn.debian.org/wsvn/pkg-perl/?sc=1&rev=57488
Log:
* Make less assumptions on precision of floating point calculations.
  (Closes: #578897)
  + new patch: long-double.patch
* Use source format 3.0 (quilt); drop README.source and quilt framework.
* Bump Standards-Version to 3.8.4 (no changes).

Added:
    trunk/libxml-xql-perl/debian/patches/long-double.patch
    trunk/libxml-xql-perl/debian/source/
    trunk/libxml-xql-perl/debian/source/format
Removed:
    trunk/libxml-xql-perl/debian/README.source
Modified:
    trunk/libxml-xql-perl/debian/changelog
    trunk/libxml-xql-perl/debian/control
    trunk/libxml-xql-perl/debian/patches/series
    trunk/libxml-xql-perl/debian/patches/spelling.patch
    trunk/libxml-xql-perl/debian/rules
    trunk/libxml-xql-perl/lib/XML/XQL.pm
    trunk/libxml-xql-perl/t/xql_sin2.t

Modified: trunk/libxml-xql-perl/debian/changelog
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/debian/changelog?rev=57488&op=diff
==============================================================================
--- trunk/libxml-xql-perl/debian/changelog (original)
+++ trunk/libxml-xql-perl/debian/changelog Wed May  5 10:22:03 2010
@@ -1,3 +1,13 @@
+libxml-xql-perl (0.68-6) unstable; urgency=low
+
+  * Make less assumptions on precision of floating point calculations.
+    (Closes: #578897)
+    + new patch: long-double.patch
+  * Use source format 3.0 (quilt); drop README.source and quilt framework.
+  * Bump Standards-Version to 3.8.4 (no changes).
+
+ -- Ansgar Burchardt <ansgar at 43-1.org>  Wed, 05 May 2010 19:20:52 +0900
+
 libxml-xql-perl (0.68-5) unstable; urgency=low
 
   [ gregor herrmann ]

Modified: trunk/libxml-xql-perl/debian/control
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/debian/control?rev=57488&op=diff
==============================================================================
--- trunk/libxml-xql-perl/debian/control (original)
+++ trunk/libxml-xql-perl/debian/control Wed May  5 10:22:03 2010
@@ -4,11 +4,11 @@
 Maintainer: Debian Perl Group <pkg-perl-maintainers at lists.alioth.debian.org>
 Uploaders: Jay Bonci <jaybonci at debian.org>,
  Ansgar Burchardt <ansgar at 43-1.org>
-Standards-Version: 3.8.3
+Standards-Version: 3.8.4
 Homepage: http://search.cpan.org/dist/XML-XQL/
 Vcs-Svn: svn://svn.debian.org/pkg-perl/trunk/libxml-xql-perl/
 Vcs-Browser: http://svn.debian.org/viewsvn/pkg-perl/trunk/libxml-xql-perl/
-Build-Depends: debhelper (>= 7.0.50~), quilt (>= 0.46-7)
+Build-Depends: debhelper (>= 7.0.50~)
 Build-Depends-Indep: perl, libdate-manip-perl (>= 5.33), libparse-yapp-perl, libxml-dom-perl (>= 1.29), libxml-regexp-perl (>= 0.03)
 
 Package: libxml-xql-perl

Added: trunk/libxml-xql-perl/debian/patches/long-double.patch
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/debian/patches/long-double.patch?rev=57488&op=file
==============================================================================
--- trunk/libxml-xql-perl/debian/patches/long-double.patch (added)
+++ trunk/libxml-xql-perl/debian/patches/long-double.patch Wed May  5 10:22:03 2010
@@ -1,0 +1,37 @@
+From: Ansgar Burchardt <ansgar at 43-1.org>
+Date: Wed, 05 May 2010 18:43:52 +0900
+Bug-Debian: http://bugs.debian.org/578897
+Forwarded: https://rt.cpan.org/Ticket/Display.html?id=57221
+Subject: Fix test failures when perl is compiled with long doubles
+
+--- libxml-xql-perl.orig/t/xql_sin2.t
++++ libxml-xql-perl/t/xql_sin2.t
+@@ -22,7 +22,7 @@
+     $^W=0;
+     my $data = join('',<DATA>);
+ #print "{{$data}}\n{{$str}}\n";
+-    assert_ok ($str eq $data);
++    assert_ok ($str =~ /^$data$/s);
+ }
+ #Test 2
+ 
+@@ -49,15 +49,15 @@
+ __DATA__
+ <array>
+   <item index='0'>
+-    <obj type='XML::XQL::Number'>0.841470984807897</obj>
++    <obj type='XML::XQL::Number'>0\.841470984807[0-9]+</obj>
+   </item>
+   <item index='1'>
+-    <obj type='XML::XQL::Number'>0.909297426825682</obj>
++    <obj type='XML::XQL::Number'>0\.909297426825[0-9]+</obj>
+   </item>
+   <item index='2'>
+-    <obj type='XML::XQL::Number'>0.141120008059867</obj>
++    <obj type='XML::XQL::Number'>0\.141120008059[0-9]+</obj>
+   </item>
+   <item index='3'>
+-    <obj type='XML::XQL::Number'>-0.756802495307928</obj>
++    <obj type='XML::XQL::Number'>-0\.756802495307[0-9]+</obj>
+   </item>
+ </array>

Modified: trunk/libxml-xql-perl/debian/patches/series
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/debian/patches/series?rev=57488&op=diff
==============================================================================
--- trunk/libxml-xql-perl/debian/patches/series (original)
+++ trunk/libxml-xql-perl/debian/patches/series Wed May  5 10:22:03 2010
@@ -1,1 +1,2 @@
 spelling.patch
+long-double.patch

Modified: trunk/libxml-xql-perl/debian/patches/spelling.patch
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/debian/patches/spelling.patch?rev=57488&op=diff
==============================================================================
--- trunk/libxml-xql-perl/debian/patches/spelling.patch (original)
+++ trunk/libxml-xql-perl/debian/patches/spelling.patch Wed May  5 10:22:03 2010
@@ -1,10 +1,19 @@
 From: Ansgar Burchardt <ansgar at 43-1.org>
-Date: Sun, 03 Jan 2010 20:02:19 +0900
+Date: Wed, 05 May 2010 18:43:52 +0900
 Subject: Fix spelling errors
 Bug: https://rt.cpan.org/Ticket/Display.html?id=54316
 
 --- libxml-xql-perl.orig/lib/XML/XQL.pm
 +++ libxml-xql-perl/lib/XML/XQL.pm
+@@ -3161,7 +3161,7 @@
+ # Text, CDATASection:
+ # - xql_data: return expanded text value
+ #
+-# -xql_element could be overriden to speed up performance
++# -xql_element could be overridden to speed up performance
+ #
+ 
+ 1;
 @@ -3363,8 +3363,8 @@
  		new XML::XQL::Date ($elem->xql_text, $elem); 
  	});
@@ -27,3 +36,12 @@
  
  =item defineTokenQ (Q)
  
+@@ -3830,7 +3830,7 @@
+ The resulting values are then casted to the type of the object with the highest
+ xql_primType() value. They are as follows: Node (0), Text (1), Number (2),
+ Boolean (3), Date (4), other data types (4 by default, but this may be
+-overriden by the user.)
++overridden by the user.)
+ 
+ E.g. if one value is a Text value and the other is a Number, the Text value is 
+ cast to a Number and the resulting low-level (Perl) comparison is (for $eq$):

Modified: trunk/libxml-xql-perl/debian/rules
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/debian/rules?rev=57488&op=diff
==============================================================================
--- trunk/libxml-xql-perl/debian/rules (original)
+++ trunk/libxml-xql-perl/debian/rules Wed May  5 10:22:03 2010
@@ -4,7 +4,7 @@
 TMP     = $(CURDIR)/debian/$(PACKAGE)
 
 %:
-	dh --with quilt $@
+	dh $@
 
 override_dh_auto_install:
 	dh_auto_install

Added: trunk/libxml-xql-perl/debian/source/format
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/debian/source/format?rev=57488&op=file
==============================================================================
--- trunk/libxml-xql-perl/debian/source/format (added)
+++ trunk/libxml-xql-perl/debian/source/format Wed May  5 10:22:03 2010
@@ -1,0 +1,1 @@
+3.0 (quilt)

Modified: trunk/libxml-xql-perl/lib/XML/XQL.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/lib/XML/XQL.pm?rev=57488&op=diff
==============================================================================
--- trunk/libxml-xql-perl/t/xql_sin2.t (original)
+++ trunk/libxml-xql-perl/t/xql_sin2.t Wed May  5 10:22:03 2010
@@ -22,7 +22,7 @@
     $^W=0;
     my $data = join('',<DATA>);
 #print "{{$data}}\n{{$str}}\n";
-    assert_ok ($str eq $data);
+    assert_ok ($str =~ /^$data$/s);
 }
 #Test 2
 
@@ -49,15 +49,15 @@
 __DATA__
 <array>
   <item index='0'>
-    <obj type='XML::XQL::Number'>0.841470984807897</obj>
+    <obj type='XML::XQL::Number'>0\.841470984807[0-9]+</obj>
   </item>
   <item index='1'>
-    <obj type='XML::XQL::Number'>0.909297426825682</obj>
+    <obj type='XML::XQL::Number'>0\.909297426825[0-9]+</obj>
   </item>
   <item index='2'>
-    <obj type='XML::XQL::Number'>0.141120008059867</obj>
+    <obj type='XML::XQL::Number'>0\.141120008059[0-9]+</obj>
   </item>
   <item index='3'>
-    <obj type='XML::XQL::Number'>-0.756802495307928</obj>
+    <obj type='XML::XQL::Number'>-0\.756802495307[0-9]+</obj>
   </item>
 </array>




More information about the Pkg-perl-cvs-commits mailing list
--- trunk/libxml-xql-perl/lib/XML/XQL.pm (original)
+++ trunk/libxml-xql-perl/lib/XML/XQL.pm Wed May  5 10:22:03 2010
@@ -3161,7 +3161,7 @@
 # Text, CDATASection:
 # - xql_data: return expanded text value
 #
 # -xql_element could be overriden to speed up performance
 #
 
 1;
@@ -3363,8 +3363,8 @@
 		new XML::XQL::Date ($elem->xql_text, $elem); 
 	});
 
-These convertors can only be specified at a global level, not on a per query
-basis. To undefine a convertor, simply pass a FUNCREF of undef.
+These converters can only be specified at a global level, not on a per query
+basis. To undefine a converter, simply pass a FUNCREF of undef.
 
 =item defineAttrValueConvertor (ELEM_TAG_NAME, ATTR_NAME, FUNCREF)
 
@@ -3378,8 +3378,8 @@
 FUNCREF should be a reference to a Perl function, e.g. \&my_sub, or
 an anonymous sub.
 
-These convertors can only be specified at a global level, not on a per query
-basis. To undefine a convertor, simply pass a FUNCREF of undef.
+These converters can only be specified at a global level, not on a per query
+basis. To undefine a converter, simply pass a FUNCREF of undef.
 
 =item defineTokenQ (Q)
 
@@ -3830,7 +3830,7 @@
 The resulting values are then casted to the type of the object with the highest
 xql_primType() value. They are as follows: Node (0), Text (1), Number (2),
 Boolean (3), Date (4), other data types (4 by default, but this may be
-overriden by the user.)
+overridden by the user.)
 
 E.g. if one value is a Text value and the other is a Number, the Text value is 
 cast to a Number and the resulting low-level (Perl) comparison is (for $eq$):
@@ -3161,7 +3161,7 @@
 # - xql_data: return expanded text value
 #
-# -xql_element could be overriden to speed up performance
+# -xql_element could be overridden to speed up performance
 #
 

Modified: trunk/libxml-xql-perl/t/xql_sin2.t
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/t/xql_sin2.t?rev=57488&op=diff
==============================================================================